@@ -64,13 +64,6 @@ test_that("testDistribution works with a multivariate normal distribution", {
 
   x <- as.data.frame(scale(mtcars[, 1:3]))
   x[1, 1] <- NA
-  expect_warning(m <- testDistribution(x, distr = "mvnormal", use = "fiml"))
-  expect_is(m, "testDistribution")
-
-  expect_invisible(td <- plot(m, plot = FALSE))
-  expect_length(td, 4)
-  expect_is(td$testDistribution, "testDistribution")
-  expect_invisible(plot(m, plot = TRUE))
 
   expect_is(
     testDistribution(x, distr = "mvnormal", use = "pairwise.complete.obs"),
@@ -83,6 +76,19 @@ test_that("testDistribution works with a multivariate normal distribution", {
     "testDistribution")
 })
 
+test_that("testDistribution works with a multivariate normal distribution and missing data", {
+  skip_on_cran()
+  x <- as.data.frame(scale(mtcars[, 1:3]))
+  x[1, 1] <- NA
+  m <- testDistribution(x, distr = "mvnormal", use = "fiml")
+  expect_is(m, "testDistribution")
+
+  expect_invisible(td <- plot(m, plot = FALSE))
+  expect_length(td, 4)
+  expect_is(td$testDistribution, "testDistribution")
+  expect_invisible(plot(m, plot = TRUE))
+})
+
 test_that("testDistribution works with a beta distribution", {
   x <- seq(.1, .9, length.out = 10)
   m <- testDistribution(x, "beta", starts = list(shape1 = 1, shape2 = 1))
@@ -133,3 +139,4 @@ test_that("testDistribution works with a negative binomial distribution", {
   expect_that(m$Data, is_a("data.table"))
 
 })
+
